@@ -1118,11 +1118,11 @@ def writeNCER(file, ncerfile, ncgr, ncer, infile, palettes, width=0, height=0, a
         basename = os.path.basename(infile).replace(".psd", "")
         # Get the layer names by using identify
         identifycmd = "magick identify -verbose " + infile
-        startupinfo = subprocess.STARTUPINFO()
-        startupinfo.dwFlags |= subprocess.STARTF_USESHOWWINDOW
         if os.name != "nt":
-            psdinfo = subprocess.check_output(shlex.split(identifycmd), startupinfo=startupinfo)
+            psdinfo = subprocess.check_output(shlex.split(identifycmd))
         else:
+            startupinfo = subprocess.STARTUPINFO()
+            startupinfo.dwFlags |= subprocess.STARTF_USESHOWWINDOW
             psdinfo = subprocess.check_output(identifycmd, startupinfo=startupinfo)
         layernames = []
         while psdinfo:
