@@ -1,6 +1,6 @@
 import pytest
 import os.path
-from hacktools import cmp_lzss
+from hacktools import cmp_lzss, cmp_cri
 
 @pytest.fixture
 def data():
@@ -21,3 +21,10 @@ def test_cmp_lz11(data):
     decmp = cmp_lzss.decompressLZ11(cmp, len(data), 1)
     assert len(data) == len(decmp)
     assert data == decmp
+
+
+def test_cmp_cri(data):
+    cmp = cmp_cri.compressCRILAYLA(data)
+    decmp = cmp_cri.decompressCRILAYLA(cmp)
+    assert len(data) == len(decmp)
+    assert data == decmp
